@@ -11,33 +11,43 @@ use Getopt::Std;
 use Video::Generator;
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
-	my ($class, @params) = @_;
+	my $class = shift;
 
 	# Create object.
 	my $self = bless {}, $class;
 
+	# Object.
+	return $self;
+}
+
+# Run script.
+sub run {
+	my $self = shift;
+
 	# Process arguments.
 	$self->{'_opts'} = {
 		'd' => 10000,
 		'f' => 60,
-		's' => '1920x1080',
 		'h' => 0,
+		's' => '1920x1080',
+		'v' => 0,
 	};
-	if (! getopts('d:f:hs:', $self->{'_opts'}) || @ARGV < 1
+	if (! getopts('d:f:hs:v', $self->{'_opts'}) || @ARGV < 1
 		|| $self->{'_opts'}->{'h'}) {
 
 		print STDERR "Usage: $0 [-d duration] [-f fps] [-h]\n\t".
-			"[-s size] [--version] output_file\n\n";
+			"[-s size] [-v] [--version] output_file\n\n";
 		print STDERR "\t-d duration\tDuration (default value is ".
 			"10000 (=10s)\n";
 		print STDERR "\t-f fps\t\tFrame rate\n";
 		print STDERR "\t-h\t\tPrint help.\n";
 		print STDERR "\t-s size\t\tSize (default value is ".
 			"1920x1080).\n";
+		print STDERR "\t-v\t\tVerbose mode.\n";
 		print STDERR "\t--version\tPrint version.\n";
 		exit 1;
 	}
@@ -50,18 +60,13 @@ sub new {
 	$self->{'_width'} = $1;
 	$self->{'_height'} = $2;
 
-	# Object.
-	return $self;
-}
-
-# Run script.
-sub run {
-	my $self = shift;
+	# Run.
 	eval {
 		my $vg = Video::Generator->new(
 			'duration' => $self->{'_opts'}->{'d'},
 			'fps' => $self->{'_opts'}->{'f'},
 			'height' => $self->{'_height'},
+			'verbose' => $self->{'_opts'}->{'v'},
 			'width' => $self->{'_width'},
 		);
 		$vg->create($self->{'_output_file'});
@@ -69,7 +74,7 @@ sub run {
 	if ($EVAL_ERROR) {
 		err 'Cannot create video.';
 	}
-	return;
+	return 0;
 }
 
 1;
@@ -161,6 +166,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
